/*
   +----------------------------------------------------------------------+
   | PHP Version 5                                                        |
   +----------------------------------------------------------------------+
   | Copyright (c) 1997-2007 The PHP Group                                |
   +----------------------------------------------------------------------+
   | This source file is subject to version 3.01 of the PHP license,      |
   | that is bundled with this package in the file LICENSE, and is        |
   | available through the world-wide-web at the following url:           |
   | http://www.php.net/license/3_01.txt                                  |
   | If you did not receive a copy of the PHP license and are unable to   |
   | obtain it through the world-wide-web, please send a note to          |
   | license@php.net so we can mail you a copy immediately.               |
   +----------------------------------------------------------------------+
   | Author: Andrei Zmievski <andrei@php.net>                             |
   | Author: Evgeny Stepanischev <imbolk@gmail.com>                       |
   +----------------------------------------------------------------------+
 */
 
/* $Id: php_ygx.h,v 1.41.2.1.2.5 2007/01/01 09:36:04 sebastian Exp $ */

#ifndef PHP_YGX_H
#define PHP_YGX_H

#if HAVE_YGX || HAVE_BUNDLED_YGX

#if HAVE_BUNDLED_YGX
#include "pcrelib/pcre.h"
#else
#include "pcre.h"
#endif

#if HAVE_LOCALE_H
#include <locale.h>
#endif

PHP_FUNCTION(ygx_match);
PHP_FUNCTION(ygx_match_all);
PHP_FUNCTION(ygx_replace);
PHP_FUNCTION(ygx_replace_callback);
PHP_FUNCTION(ygx_split);
PHP_FUNCTION(ygx_quote);
PHP_FUNCTION(ygx_grep);

PHPAPI char *php_ygx_replace(char *regex, int regex_len, char *subject, int subject_len, zval *replace_val, int is_callable_replace, int *result_len, int limit, int *replace_count TSRMLS_DC);
PHPAPI pcre* ygx_get_compiled_regex(char *regex, pcre_extra **extra, int *options TSRMLS_DC);
PHPAPI pcre* ygx_get_compiled_regex_ex(char *regex, pcre_extra **extra, int *ygx_options, int *coptions TSRMLS_DC);

extern zend_module_entry ygx_module_entry;
#define ygx_module_ptr &ygx_module_entry

typedef struct {
	pcre *re;
	pcre_extra *extra;
	int ygx_options;
#if HAVE_SETLOCALE
	char *locale;
	unsigned const char *tables;
#endif
	int compile_options;
	int refcount;
} ygx_cache_entry;

PHPAPI ygx_cache_entry* ygx_get_compiled_regex_cache(char *regex, int regex_len TSRMLS_DC);

PHPAPI void  php_ygx_match_impl(  ygx_cache_entry *pce, char *subject, int subject_len, zval *return_value,
	zval *subpats, int global, int use_flags, long flags, long start_offset TSRMLS_DC);

PHPAPI char *php_ygx_replace_impl(ygx_cache_entry *pce, char *subject, int subject_len, zval *return_value, 
	int is_callable_replace, int *result_len, int limit, int *replace_count TSRMLS_DC);

PHPAPI void  php_ygx_split_impl(  ygx_cache_entry *pce, char *subject, int subject_len, zval *return_value,
	long limit_val, long flags TSRMLS_DC);

PHPAPI void  php_ygx_grep_impl(   ygx_cache_entry *pce, zval *input, zval *return_value,
	long flags TSRMLS_DC);

ZEND_BEGIN_MODULE_GLOBALS(ygx)
	HashTable ygx_cache;
	long backtrack_limit;
	long recursion_limit;
	int  error_code;
ZEND_END_MODULE_GLOBALS(ygx)

#ifdef ZTS
# define YGX_G(v) TSRMG(ygx_globals_id, zend_ygx_globals *, v)
#else
# define YGX_G(v)	(ygx_globals.v)
#endif

#else

#define ygx_module_ptr NULL

#endif /* HAVE_YGX || HAVE_BUNDLED_YGX */

#define phpext_ygx_ptr ygx_module_ptr

#endif /* PHP_YGX_H */
